@@ -13,6 +13,8 @@ except ImportError:
     # of ordered dict for python2.6 if we felt this was important.
     OrderedDict = dict
 
+from botocore import xform_name
+
 
 class ModelFiles(object):
     """Container object to hold all the various parsed json files.
@@ -75,10 +77,14 @@ def add_pagination_configs(new_model, pagination):
     # Adding in pagination configs means copying the config to a top level
     # 'pagination' key in the new model, and it also means adding the
     # pagination config to each individual operation.
+    # Also, the input_token needs to be transformed to the python specific
+    # name, so we're adding a py_input_token (e.g. NextToken -> next_token).
     if pagination:
         new_model['pagination'] = pagination
     for name in pagination:
         config = pagination[name]
+        if 'py_input_token' not in config:
+            config['py_input_token'] = xform_name(config['input_token'])
         operation = new_model['operations'].get(name)
         if operation is None:
             raise ValueError("Tried to add a pagination config for non "
